﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using Xamarin.Forms;
using Xamarin.Forms.Xaml;

namespace sfListView.Controls
{
    [XamlCompilation(XamlCompilationOptions.Compile)]
    public partial class NavbarTop : ContentView
    {
        public static readonly BindableProperty PageTitelProperty = BindableProperty.Create(
            propertyName: "PageTitel",
            defaultValue: String.Empty,
            returnType: typeof(string),
            declaringType: typeof(NavbarTop),
            defaultBindingMode: BindingMode.TwoWay,
            propertyChanged: PageTitelPropertyChanged);

        public string PageTitel
        {
            get { return base.GetValue(PageTitelProperty).ToString(); }
            set { base.SetValue(PageTitelProperty, value); }
        }

        private static void PageTitelPropertyChanged(BindableObject bindable, object oldValue, object newValue)
        {
            var thisControl = (NavbarTop)bindable;
            thisControl.PageTitle.Text = (string)newValue;
        }




        public static readonly BindableProperty IsVisibleBackProperty = BindableProperty.Create(
            propertyName: "IsVisibleBack",
            defaultValue: bool.TrueString,
            returnType: typeof(string),
            declaringType: typeof(NavbarTop),
            defaultBindingMode: BindingMode.TwoWay,
            propertyChanged: IsVisibleBackPropertyChanged);

        public string IsVisibleBack
        {
            get { return base.GetValue(IsVisibleBackProperty).ToString(); }
            set { base.SetValue(IsVisibleBackProperty, value); }
        }

        private static void IsVisibleBackPropertyChanged(BindableObject bindable, object oldValue, object newValue)
        {
            var thisControl = (NavbarTop)bindable;
            thisControl.backImage.IsVisible = Convert.ToBoolean(newValue);
        }




        public static readonly BindableProperty IsVisibleDashboardProperty = BindableProperty.Create(
            propertyName: "IsVisibleDashboard",
            defaultValue: bool.TrueString,
            returnType: typeof(string),
            declaringType: typeof(NavbarTop),
            defaultBindingMode: BindingMode.TwoWay,
            propertyChanged: IsVisibleDashboardPropertyChanged);

        public string IsVisibleDashboard
        {
            get { return base.GetValue(IsVisibleDashboardProperty).ToString(); }
            set { base.SetValue(IsVisibleDashboardProperty, value); }
        }

        private static void IsVisibleDashboardPropertyChanged(BindableObject bindable, object oldValue, object newValue)
        {
            var thisControl = (NavbarTop)bindable;
            thisControl.Dashboard.IsVisible = Convert.ToBoolean(newValue);
        }




        public NavbarTop()
        {
            InitializeComponent();

            TapGestureRecognizer backtap = new TapGestureRecognizer();
            backtap.Command = new Command(OnClickedBack);
            backImage.GestureRecognizers.Add(backtap);

            TapGestureRecognizer dashboardtap = new TapGestureRecognizer();
            dashboardtap.Command = new Command(OnClickedDashboard);
            Dashboard.GestureRecognizers.Add(dashboardtap);

        }


        public event EventHandler ClickedBack;
        public void OnClickedBack(object sender)
        {
            if (ClickedBack != null)
            {
                this.ClickedBack(this, EventArgs.Empty);
            }
        }


        public event EventHandler ClickedDashboard;
        public void OnClickedDashboard(object sender)
        {
            if (ClickedDashboard != null)
            {
                this.ClickedDashboard(this, EventArgs.Empty);
            }
        }




    }
}