﻿using sfListView.Models;
using sfListView.Services;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using Xamarin.Forms;

namespace sfListView.ViewModels
{

    public class EventsViewModel : INotifyPropertyChanged
    {
        private EventsService eventsService;

        public EventsViewModel()
        {
            eventsService = new EventsService();


            InitializeDataAsync();
        }


        private async void InitializeDataAsync()
        {
            await GetAllAsync();
        }

        public async Task GetAllAsync()
        {
            Events = await eventsService.GetEventsAsync();
            Events = new ObservableCollection<EventForListDto>();
            Events.Add(GenerateItem(1));
            Events.Add(GenerateItem(2));
            Events.Add(GenerateItem(3));
            Events.Add(GenerateItem(4));
            Events.Add(GenerateItem(5));
            filteredEvents = Events;
            FillCategories();
        }
        private EventForListDto GenerateItem(int index)
        {
            EventForListDto item = new EventForListDto();
            List<SharedDto> amenities = new List<SharedDto>();
            amenities.Add(new SharedDto() { Name = "Shared" + index });
            amenities.Add(new SharedDto() { Name = "Shared" + (index + 1) });
            item.Amenities = amenities;
            List<string> boxoffice = new List<string>();
            boxoffice.Add("1");
            boxoffice.Add("2");
            item.Categories = amenities;
            item.CategoryName = "Category" + index;
            item.Description = "Description" + index;
            item.DistanceFromUser = 50;
            item.FormatedFrom = "FFrom" + index;
            item.FormatedTo = "Fto" + index;
            item.FormatedToWithYear = "Fyear" + index;
            item.From = DateTime.Now;
            List<GalleryDto> galleries = new List<GalleryDto>();
            galleries.Add(new GalleryDto() { Image = "" });
            item.Gallery = galleries;
            item.Guid = "guid" + index;
            item.Id = index;
            item.IsFavorite = true;
            item.IsRegisterd = true;
            item.Location = "location" + index;
            item.LocationAddress = "address" + index;
            item.MaximumSeats = 3;
            item.Name = "Name" + index;
            item.Phone = "1234567890";
            item.RegisteredSeats = 2;
            item.RemainingSeats = 1;
            item.Subtitle = "subtitle" + index;
            item.To = DateTime.Now.AddDays(1);
            item.Website = "www.temp.com";
            return item;
        }

        private ObservableCollection<string> _selectedCategories = new ObservableCollection<string>();

        public ObservableCollection<string> selectedCategories
        {
            get { return _selectedCategories; }
            set { _selectedCategories = value; }
        }

        /// <summary>
        /// filter command for Custom buttons in listview header
        /// </summary>
        public ICommand FilterSearch
        {
            get
            {
                return new Command<string>((key) =>
                {
                    try
                    {
                        isRefreshing = true;
                        if (key != null)
                        {
                            if (!string.IsNullOrEmpty(key) && !string.IsNullOrWhiteSpace(key))
                            {
                                if (key == "ALL" || key.Contains("UpForFirst"))
                                    filteredEvents = Events;
                                else
                                    filteredEvents = Events.Where(attraction => attraction.Categories.Any(c => c.Name == key))
                                        .ToObservableCollection();
                                currentCategory = key;
                            }
                            else
                            {
                            }
                        }
                    }
                    catch
                    {
                        //MessageInterface = "please check your connection and try again";
                    }
                    isRefreshing = false;
                });
            }
        }



        public ICommand OnRefreshListViewCommad
        {
            get
            {
                return new Command(async () =>
                {
                    try
                    {
                        await GetAllAsync();
                        currentCategory = "ALL";
                    }
                    catch
                    {
                        //MessageInterface = "please check your connection and try again";
                    }
                    isRefreshing = false;
                });
            }
        }


        /// <summary>
        /// refreshing for PullToRefreshView 
        /// </summary>
        /// <returns>Void</returns>
        public async Task OnRefreshListView()
        {
            isRefreshing = true;
            await GetAllAsync();
            currentCategory = "ALL";
            isRefreshing = false;
        }


        /// <summary>
        /// current selected category
        /// </summary>
        public string currentCategory { get; set; }

        /// <summary>
        /// filter command for categories buttons in listview header
        /// </summary>
        public ICommand Filter
        {
            get
            {
                return new Command<string>((key) =>
                {
                    try
                    {
                        isRefreshing = true;
                        if (key != currentCategory)
                        {
                            if (!string.IsNullOrEmpty(key) && !string.IsNullOrWhiteSpace(key))
                            {
                                if (key == "ALL" || key.Contains("UpForFirst"))
                                    filteredEvents = Events;
                                else
                                    filteredEvents = Events.Where(attraction => attraction.Categories.Any(c => c.Name == key))
                                        .ToObservableCollection();
                                currentCategory = key;
                            }
                            else
                            {
                            }
                        }
                    }
                    catch
                    {
                        //MessageInterface = "please check your connection and try again";
                    }
                    isRefreshing = false;
                });
            }
        }


        /// <summary>
        /// pullToRefresh view isRefreshing
        /// </summary>
        private bool _isRefreshing;
        public bool isRefreshing
        {
            get { return _isRefreshing; }
            set
            {
                _isRefreshing = value;
                OnPropertyChanged(nameof(isRefreshing));
            }
        }

        /// <summary>
        /// Events
        /// </summary>
        private ObservableCollection<EventForListDto> _events = new ObservableCollection<EventForListDto>();
        public ObservableCollection<EventForListDto> Events
        {
            get => _events;
            set
            {
                _events = value;
                OnPropertyChanged(nameof(Events));
            }
        }

        /// <summary>
        /// filtered data for listview
        /// </summary>
        private ObservableCollection<EventForListDto> _filteredEvents;
        public ObservableCollection<EventForListDto> filteredEvents
        {
            get => _filteredEvents;
            set
            {
                _filteredEvents = value;
                OnPropertyChanged("filteredEvents");
            }
        }


        /// <summary>
        /// page categories 
        /// </summary>
        private ObservableCollection<string> _categories = new ObservableCollection<string>();
        public ObservableCollection<string> categories
        {
            get => _categories;
            set
            {
                _categories = value;
                OnPropertyChanged(nameof(categories));
            }
        }


        /// <summary>
        /// add attractions categories to Categories ObservableCollection
        /// used to add categories buttons
        /// </summary>
        public void FillCategories()
        {
            if (Events == null)
            {
                return;
            }
            categories.Clear();
            categories.Add("ALL");
            foreach (var item in Events)
            {
                if (!categories.Contains(item.Categories[0].Name))
                {
                    categories.Add(item.Categories[0].Name);
                }
            }
        }







        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

    }
}
